@@ -135,6 +135,18 @@ void LanFlashLED::toggleTorch()
 }
 
 
+void LanFlashLED::turnTorchOn()
+{
+  if (!torchOn) toggleTorch();
+}
+
+
+void LanFlashLED::turnTorchOff()
+{
+  if (torchOn) toggleTorch();
+}
+
+
 int LanFlashLED::getMinFlash()
 {
   return minFlash;
@@ -159,6 +171,12 @@ int LanFlashLED::getMaxTime()
 }
 
 
+int LanFlashLED::getChosenTime()
+{
+  return chosenTime;
+}
+
+
 void LanFlashLED::setFlashBrightness(
   int brightness)
 {
